@@ -1,33 +1,35 @@
 #' @title Generate dummy variables for factor features.
 #'
 #' @description
-#' Replace all factor features with their dummy variables. Internally \code{\link{model.matrix}} is used.
+#' Replace all factor features with their dummy variables. Internally [model.matrix] is used.
 #' Non factor features will be left untouched and passed to the result.
 #'
 #' @template arg_taskdf
 #' @template arg_taskdf_target
-#' @param method [\code{character(1)}]\cr
+#' @param method (`character(1)`)\cr
 #'   Available are:
 #'   \describe{
 #'     \item{"1-of-n":}{For n factor levels there will be n dummy variables.}
 #'     \item{"reference":}{There will be n-1 dummy variables leaving out the first factor level of each variable.}
 #'   }
 #'   Default is \dQuote{1-of-n}.
-#' @param cols [\code{character}]\cr
+#' @param cols ([character])\cr
 #'   Columns to create dummy features for. Default is to use all columns.
 #' @template ret_taskdf
 #' @export
 #' @family eda_and_preprocess
 createDummyFeatures = function(obj, target = character(0L), method = "1-of-n", cols = NULL) {
   assertChoice(method, choices = c("1-of-n", "reference"))
-  if (!is.factor(obj) && !is.character(obj))
+  if (!is.factor(obj) && !is.character(obj)) {
     checkTargetPreproc(obj, target, cols)
+  }
   UseMethod("createDummyFeatures")
 }
 
 #' @export
 createDummyFeatures.data.frame = function(obj, target = character(0L), method = "1-of-n", cols = NULL) {
-    # get all factor feature names present in data
+
+  # get all factor feature names present in data
   work.cols = colnames(obj)[vlapply(obj, is.factor)]
   work.cols = setdiff(work.cols, target)
 
@@ -43,13 +45,14 @@ createDummyFeatures.data.frame = function(obj, target = character(0L), method =
   options(na.action = "na.pass")
 
   prefix = colnames(obj[work.cols])
-  dfcol = obj[,work.cols]
+  dfcol = obj[, work.cols]
 
   dummies = as.data.frame(lapply(obj[work.cols], createDummyFeatures, method = method))
 
   if (method == "reference" && length(work.cols) == length(dummies)) {
     colnames(dummies) = Map(function(col, pre) {
-      stri_paste(pre, tail(levels(col), -1), sep = ".")}, obj[work.cols], prefix)
+      stri_paste(pre, tail(levels(col), -1), sep = ".")
+    }, obj[work.cols], prefix)
   }
 
   if (length(dummies) != 0) {
