@@ -25,27 +25,23 @@
 #'   Should the downsampled data be stratified according to the target classes?
 #' @template arg_showinfo
 #' @return ([LearningCurveData]). A `list` containing:
-#'   \item{task}{[[Task])\cr
-#'     The task.}
-#'   \item{measures}{[(list of) [Measure])\cr
-#'     Performance measures.}
-#'   \item{data}{([data.frame]) with columns:
-#'     \itemize{
-#'       \item `learner` Names of learners.
-#'       \item `percentage` Percentages drawn from the training split.
-#'       \item One column for each
-#'     [Measure] passed to [generateLearningCurveData].
-#'    }}
+#'   - The [Task]
+#'   - List of [Measure])\cr
+#'     Performance measures
+#'   - data ([data.frame]) with columns:
+#'       - `learner` Names of learners.
+#'       - `percentage` Percentages drawn from the training split.
+#'       - One column for each [Measure] passed to [generateLearningCurveData].
 #' @examples
 #' r = generateLearningCurveData(list("classif.rpart", "classif.knn"),
-#' task = sonar.task, percs = seq(0.2, 1, by = 0.2),
-#' measures = list(tp, fp, tn, fn), resampling = makeResampleDesc(method = "Subsample", iters = 5),
-#' show.info = FALSE)
+#'   task = sonar.task, percs = seq(0.2, 1, by = 0.2),
+#'   measures = list(tp, fp, tn, fn),
+#'   resampling = makeResampleDesc(method = "Subsample", iters = 5),
+#'   show.info = FALSE)
 #' plotLearningCurve(r)
-#' @noMd
 #' @export
 generateLearningCurveData = function(learners, task, resampling = NULL,
-  percs = seq(0.1, 1, by = 0.1), measures, stratify = FALSE, show.info = getMlrOption("show.info"))  {
+  percs = seq(0.1, 1, by = 0.1), measures, stratify = FALSE, show.info = getMlrOption("show.info")) {
 
   learners = ensureVector(learners, 1, "Learner")
   learners = lapply(learners, checkLearner)
@@ -54,10 +50,11 @@ generateLearningCurveData = function(learners, task, resampling = NULL,
   measures = checkMeasures(measures, task)
   assertFlag(stratify)
 
-  if (is.null(resampling))
+  if (is.null(resampling)) {
     resampling = makeResampleInstance("Holdout", task = task)
-  else
+  } else {
     assert(checkClass(resampling, "ResampleDesc"), checkClass(resampling, "ResampleInstance"))
+  }
 
   # create downsampled versions for all learners
   lrnds1 = lapply(learners, function(lrn) {
@@ -74,12 +71,12 @@ generateLearningCurveData = function(learners, task, resampling = NULL,
   lrnds2 = unlist(lrnds1, recursive = FALSE)
   dsws = extractSubList(lrnds2, "lrn", simplify = FALSE)
 
-  bench.res = benchmark(dsws, task, resampling,  measures, show.info = show.info)
+  bench.res = benchmark(dsws, task, resampling, measures, show.info = show.info)
   perfs = getBMRAggrPerformances(bench.res, as.df = TRUE)
 
   # get perc and learner col data
-  perc = extractSubList(lrnds2[perfs$learner.id], "perc")
-  learner = extractSubList(lrnds2[perfs$learner.id], "lrn.id")
+  perc = extractSubList(lrnds2[as.factor(perfs$learner.id)], "perc")
+  learner = extractSubList(lrnds2[as.factor(perfs$learner.id)], "lrn.id")
   perfs = dropNamed(perfs, c("task.id", "learner.id"))
 
   # set short measures names and resort cols
@@ -122,6 +119,7 @@ print.LearningCurveData = function(x, ...) {
 #' @export
 plotLearningCurve = function(obj, facet = "measure", pretty.names = TRUE,
   facet.wrap.nrow = NULL, facet.wrap.ncol = NULL) {
+
   assertClass(obj, "LearningCurveData")
   mappings = c("measure", "learner")
   assertChoice(facet, mappings)
@@ -138,15 +136,18 @@ plotLearningCurve = function(obj, facet = "measure", pretty.names = TRUE,
   nlearn = length(unique(data$learner))
   nmeas = length(unique(data$measure))
 
-  if ((color == "learner" & nlearn == 1L) | (color == "measure" & nmeas == 1L))
+  if ((color == "learner" & nlearn == 1L) | (color == "measure" & nmeas == 1L)) {
     color = NULL
-  if ((facet == "learner" & nlearn == 1L) | (facet == "measure" & nmeas == 1L))
+  }
+  if ((facet == "learner" & nlearn == 1L) | (facet == "measure" & nmeas == 1L)) {
     facet = NULL
+  }
 
-  if (!is.null(color))
+  if (!is.null(color)) {
     plt = ggplot(data, aes_string(x = "percentage", y = "performance", colour = color))
-  else
+  } else {
     plt = ggplot(data, aes_string(x = "percentage", y = "performance"))
+  }
   plt = plt + geom_point()
   plt = plt + geom_line()
   if (!is.null(facet)) {
