@@ -6,7 +6,7 @@ test_that("UnsupervisedTask", {
   expect_error(makeClassifTask(data = 44), "'data.frame'")
 
   # wrong vars
-  expect_error(subsetTask(noclass.task, vars = c("Sepal.Length", "x", "y")))
+  expect_error(subsetTask(noclass.task, features = c("Sepal.Length", "x", "y")))
 
   # subsetTask works with index vector
   sub.task = subsetTask(noclass.task, features = 1:2)
@@ -23,7 +23,7 @@ test_that("UnsupervisedTask", {
   # check that blocking is still there after subsetting
   ct1 = makeClusterTask(data = noclass.df, blocking = as.factor(seq_len(nrow(noclass.df))))
   expect_true(getTaskDesc(ct1)$has.blocking)
-  ct2 = subsetTask(ct1)
+  ct2 = subsetTask(ct1, features = getTaskFeatureNames(ct1))
   expect_true(getTaskDesc(ct2)$has.blocking)
 
   # check 'fixup data' works
