@@ -16,8 +16,10 @@ test_that("regr_plsr", {
     pars = list(regr.formula, data = regr.train)
     pars = c(pars, parset)
     m = do.call(pls::plsr, pars)
-    old.predicts.list[[i]] = pls:::predict.mvr(m, newdata = regr.test, comps = 1:m$ncomp)[, 1]
+    old.predicts.list[[i]] = pls:::predict.mvr(m, newdata = regr.test,
+      comps = 1:m$ncomp)[, 1]
   }
 
-  testSimpleParsets("regr.plsr", regr.df, regr.target, regr.train.inds, old.predicts.list, parset.list)
+  testSimpleParsets("regr.plsr", regr.df, regr.target, regr.train.inds,
+    old.predicts.list, parset.list)
 })
