@@ -16,8 +16,11 @@ test_that("surv_cv.CoxBoost", {
     colnames(y) = c("time", "status")
     x = dropNamed(surv.train, surv.target)
 
-    info = getFixDataInfo(surv.train, factors.to.dummies = TRUE, ordered.to.int = TRUE)
-    pars = c(list(time = unname(y[, surv.target[1]]), status = unname(y[, surv.target[2]]), x = as.matrix(fixDataForLearner(x, info))), parset)
+    info = getFixDataInfo(surv.train, factors.to.dummies = TRUE,
+      ordered.to.int = TRUE)
+    pars = c(list(time = unname(y[, surv.target[1]]),
+      status = unname(y[, surv.target[2]]), x = as.matrix(fixDataForLearner(x,
+        info))), parset)
     if (is.null(pars$penalty)) {
       pars$penalty = penalty = 9 * sum(unname(y[, surv.target[2]]))
     }
@@ -28,11 +31,14 @@ test_that("surv_cv.CoxBoost", {
     pars$K = NULL
     pars$maxstepno = NULL
     m = do.call(CoxBoost::CoxBoost, pars)
-    p = as.numeric(predict(m, newdata = as.matrix(fixDataForLearner(dropNamed(surv.test, surv.target), info)), type = "lp"))
+    p = as.numeric(predict(m,
+      newdata = as.matrix(fixDataForLearner(dropNamed(surv.test, surv.target),
+        info)), type = "lp"))
     old.predicts.list[[i]] = as.numeric(p)
   }
 
-  testSimpleParsets("surv.cv.CoxBoost", surv.df, surv.target, surv.train.inds, old.predicts.list, parset.list)
+  testSimpleParsets("surv.cv.CoxBoost", surv.df, surv.target, surv.train.inds,
+    old.predicts.list, parset.list)
 
   if (FALSE) {
     lrn = makeLearner("surv.cv.CoxBoost")
