@@ -10,19 +10,22 @@ test_that("makeModelMultiplexerParamSet works", {
 
   ps1 = makeModelMultiplexerParamSet(lrn,
     makeNumericParam("sigma", lower = -10, upper = 10, trafo = function(x) 2^x),
-    makeIntegerParam("ntree", lower = 1L, upper = 500L)
+    makeIntegerParam("ntree", lower = 1L, upper = 50L)
   )
 
   ps2 = makeModelMultiplexerParamSet(lrn,
-    classif.ksvm = makeParamSet(makeNumericParam("sigma", lower = -10, upper = 10, trafo = function(x) 2^x)),
-    classif.randomForest = makeParamSet(makeIntegerParam("ntree", lower = 1L, upper = 500L))
+    classif.ksvm = makeParamSet(makeNumericParam("sigma", lower = -10,
+      upper = 10, trafo = function(x) 2^x)),
+    classif.randomForest = makeParamSet(makeIntegerParam("ntree", lower = 1L,
+      upper = 50L))
   )
 
   ps3 = makeParamSet(
     makeDiscreteParam("selected.learner", values = extractSubList(bls, "id")),
-    makeNumericParam("classif.ksvm.sigma", lower = -10, upper = 10, trafo = function(x) 2^x,
+    makeNumericParam("classif.ksvm.sigma", lower = -10, upper = 10,
+      trafo = function(x) 2^x,
       requires = quote(selected.learner == "classif.ksvm")),
-    makeIntegerParam("classif.randomForest.ntree", lower = 1L, upper = 500L,
+    makeIntegerParam("classif.randomForest.ntree", lower = 1L, upper = 50L,
       requires = quote(selected.learner == "classif.randomForest"))
   )
 
@@ -37,12 +40,15 @@ test_that("ModelMultiplexer basic stuff works", {
   expect_equal(class(lrn), c("ModelMultiplexer", "BaseEnsemble", "Learner"))
 
   # check hyper par setting and so on
-  lrn2 = setHyperPars(lrn, selected.learner = "classif.rpart", classif.rpart.minsplit = 10000L)
+  lrn2 = setHyperPars(lrn, selected.learner = "classif.rpart",
+    classif.rpart.minsplit = 10000L)
   xs = getHyperPars(lrn2)
-  expect_true(setequal(names(xs), c("selected.learner", "classif.rpart.minsplit", "classif.rpart.xval")))
+  expect_true(setequal(names(xs), c("selected.learner",
+    "classif.rpart.minsplit", "classif.rpart.xval")))
   expect_equal(xs$classif.rpart.minsplit, 10000L)
   mod = train(lrn2, task = binaryclass.task)
-  expect_equal(getLearnerModel(mod, more.unwrap = TRUE)$control$minsplit, 10000L)
+  expect_equal(getLearnerModel(mod, more.unwrap = TRUE)$control$minsplit,
+    10000L)
 
   # check removal
   lrn3 = removeHyperPars(lrn2, "classif.rpart.minsplit")
@@ -53,12 +59,14 @@ test_that("ModelMultiplexer basic stuff works", {
   lrn2 = setPredictType(lrn, "prob")
   mod = train(lrn2, task = binaryclass.task)
   p = predict(mod, task = binaryclass.task)
-  expect_numeric(getPredictionProbabilities(p), any.missing = FALSE, lower = 0, upper = 1)
+  expect_numeric(getPredictionProbabilities(p), any.missing = FALSE, lower = 0,
+    upper = 1)
 })
 
 test_that("FailureModel works", {
   lrn = list(
-    makeLearner("classif.__mlrmocklearners__2", config = list(on.learner.error = "warn")),
+    makeLearner("classif.__mlrmocklearners__2",
+      config = list(on.learner.error = "warn")),
     makeLearner("classif.rpart", config = list(on.learner.error = "warn"))
   )
   lrn = makeModelMultiplexer(lrn)
@@ -85,6 +93,8 @@ test_that("FailureModel works", {
 })
 
 test_that("ModelMultiplexer tuning", {
+  skip("Until irace works with R 4.0")
+
   lrn = makeModelMultiplexer(c("classif.knn", "classif.rpart"))
   rdesc = makeResampleDesc("CV", iters = 2L)
 
@@ -92,14 +102,16 @@ test_that("ModelMultiplexer tuning", {
     makeIntegerParam("minsplit", lower = 1, upper = 50))
   # tune with random
   ctrl = makeTuneControlRandom(maxit = 4L)
-  res = tuneParams(lrn, binaryclass.task, rdesc, par.set = tune.ps, control = ctrl)
+  res = tuneParams(lrn, binaryclass.task, rdesc, par.set = tune.ps,
+    control = ctrl)
   expect_true(setequal(class(res), c("TuneResult", "OptResult")))
   y = getOptPathY(res$opt.path)
   expect_true(all(!is.na(y)))
   expect_true(all(is.finite(y)))
   # tune with irace
   task = subsetTask(binaryclass.task, subset = c(1:20, 150:170))
-  ctrl = makeTuneControlIrace(maxExperiments = 40L, nbIterations = 2L, minNbSurvival = 1L)
+  ctrl = makeTuneControlIrace(maxExperiments = 40L, nbIterations = 2L,
+    minNbSurvival = 1L)
   res = tuneParams(lrn, task, rdesc, par.set = tune.ps, control = ctrl)
   expect_true(setequal(class(res), c("TuneResult", "OptResult")))
   y = getOptPathY(res$opt.path)
@@ -115,8 +127,8 @@ test_that("ModelMultiplexer inherits predict.type from base learners", {
   )
   learner = makeModelMultiplexer(base.learners)
   expect_equal(learner$predict.type, "prob")
-  # now lets see that the next code runs and does not complain about matrix output for
-  # base learner predict output
+  # now lets see that the next code runs and does not complain about matrix
+  # output for base learner predict output
   r = holdout(learner, binaryclass.task)
 
   # now check that we can tune the threshold
@@ -126,7 +138,8 @@ test_that("ModelMultiplexer inherits predict.type from base learners", {
   )
   rdesc = makeResampleDesc("Holdout")
   ctrl = makeTuneControlGrid(tune.threshold = TRUE)
-  res = tuneParams(learner, binaryclass.task, resampling = rdesc, par.set = ps, control = ctrl)
+  res = tuneParams(learner, binaryclass.task, resampling = rdesc, par.set = ps,
+    control = ctrl)
 })
 
 # we had bug here, see issue #647
@@ -167,7 +180,8 @@ test_that("ModelMultiplexer passes on hyper pars in predict with both", {
   test.ps$fix.factors.prediction = TRUE
 
   opts = NULL
-  trainLearner.test.ps = function(.learner, .task, .subset, .weights = NULL, ...) {
+  trainLearner.test.ps = function(.learner, .task, .subset, .weights = NULL,
+    ...) {
     opts <<- list(...) # nolint
     # the following to make the type checking happy
     list(dummy = getTaskData(.task, .subset)[[getTaskTargetNames(.task)[1]]][1])
@@ -181,7 +195,8 @@ test_that("ModelMultiplexer passes on hyper pars in predict with both", {
   registerS3method("predictLearner", "test.ps", predictLearner.test.ps)
 
   test.ps.mm = makeModelMultiplexer(list(test.ps))
-  test.ps.mm.args = setHyperPars(test.ps.mm, test.ps.tpTRAIN = 1, test.ps.tpPREDICT = 2, test.ps.tpBOTH = 3)
+  test.ps.mm.args = setHyperPars(test.ps.mm, test.ps.tpTRAIN = 1,
+    test.ps.tpPREDICT = 2, test.ps.tpBOTH = 3)
   trained = train(test.ps.mm.args, pid.task)
   expect_false(is.null(opts$tpBOTH))
   expect_false(is.null(opts$tpTRAIN))
